#################################################################################
# Created       : Martin Foster
# Modified      : 02/26/2000
#################################################################################
#
# DBM - Modules part of Webchat designed to hide DBM  
# Copyright (C) 2000  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : mfoster@redwhite.com
#       Address : Suite 209 - 355 5th Ave NE
#                 Calgary, Alberta
#                 T2R 0K9
#
#################################################################################

package Webchat::Dbm;


#################################################################################
# Data Members
#################################################################################

#####################
# File locations
$prefix	   = '/usr/share/webchat'; 				# Prefix to dbm directory

$mysql     = "$prefix/mysql";					# MySQL connect dbm
$realm     = "$prefix/realm";					# Realm tags dbm
$portal    = "$prefix/portal";					# Portal tags dbm
$login     = "$prefix/login";					# Login tags dbm                                
$config    = "$prefix/config";					# Configuration tags dbm
$chat      = "$prefix/chat";					# Chat tags dbm
$system    = "$prefix/system";					# System information dbm

$bypass    = 0;							# Bypass filecheck (default no)


#################################################################################
# Sub-Routines
#################################################################################

#####################
# DBMClose
#
# Sub-Routine designed to hide the ugliness of dbmclose.  Unlike it's cousin
# dbmopen it will not kill the program, merely warn one.

sub DBMClose
{
	#####################
	# Data members	
	$hash = shift;						# Reference to hash

	#####################
	# Program area
	dbmclose(%{$hash})					# Unlink DBM from Hash
		or warn("Open DBM error : $!");			# Or die
}


#####################
# DBMOpen
#
# Sub-Routine designed to hide the ugliness of dbmopen and dbmclose.   While may
# not be needed in general use.  This allows to open specific hashes without much
# headache, as you call a subroutine instead of a function with all arguments.

sub DBMOpen							# Hash referece, filename
{
	#####################
	# Data members	
	$hash = shift;						# Reference to hash
	$file = shift;						# Non referece to file
	$choice = shift;					# Choice of operations 

	#####################
	# Program area

	# If bypass is disabled
	unless ($bypass)
	{ 
		# Do file check for read and existence
		if ((-f $file) && (-R $file))
		{
			dbmopen(%{$hash}, $file, 0644)		# Link DBM to Hash
				or die("Open DBM error : $!");	# Or die
		}

		# If check fails reset
		else
		{ 
			DBMReset($choice); 			# Call and reset to defaults
			warn("DBM $file was reset"); 
		}
	}

	# If bypass is enabled
	else
	{	
		dbmopen(%{$hash}, $file, 0644)			# Link DBM to Hash
			or die("Open DBM error : $!");		# Or die
	}
}

# Alias for MySQL dbm
sub DBMOpenMySQL
{ DBMOpen(shift, $mysql, 0); }

# Alias for Realm dbm
sub DBMOpenRealm
{ DBMOpen(shift, $realm, 1); }

# Alias for Portal dbm
sub DBMOpenPortal
{ DBMOpen(shift, $portal, 2); }

# Alias for Login dbm
sub DBMOpenLogin
{ DBMOpen(shift, $login, 3); }

# Alias for Configuration dbm
sub DBMOpenConfiguration
{ DBMOpen(shift, $config, 4); }

# Alias for Configuration dbm
sub DBMOpenConfig
{ DBMOpen(shift, $config, 4); }

# Alias for chat dbm
sub DBMOpenChat
{ DBMOpen(shift, $chat, 5); }

# Alias for System dbm
sub DBMOpenSystem
{ DBMOpen(shift, $system, 6); }



#####################
# DBMReset
#
# Resets all DBMs to their default values.   While this sub-routine is rarely
# used, it nicely fits with this Module.

sub DBMReset							# Choice
{
	#####################
	# Data members

	my %mysql; 						# MySQL connect
	my %realm;						# Realm tags
	my %portal;						# Portal tags
	my %login;						# Login tags
	my %config;						# Configuration
	my %chat;						# Chat
	my %system;						# System settings

	my $action = shift;					# Action to take


	#####################
	# Program area

	$bypass = 1;						# Enable file check bypass


	# MySQL
	#
	# Needed information to connect to the MySQL database without which
	# connection would not be possible.

	if ($choice == 0)
	{
		DBMOpenMySQL(\%mysql);
		%mysql = (
			'SetServer'		=> 'localhost',			# Server name
			'SetDatabase'		=> 'webchat',			# Database name
			'SetUser'		=> 'webchat',			# Username 
			'SetPass'		=> 'CHANGE',			# Password used
			'SetPort'		=> '3306'			# Default port
		);
	}

	# Realm
	#
	# Information to change format and language of Realms

	elsif ($choice == 1)
	{
		DBMOpenRealm(\%realm);
		%realm = (
			# Tags
			'TagTitle'		=> 'Realm Title',		# Realm title	
			'TagTitlePortal'	=> 'Portal',			# Portal link
			'TagTitlePrivate'	=> 'Private Message',		# Private message link
			'TagTitleWho'		=> 'Who is on',			# Who is on link
			'TagTitleConfIgnore'	=> 'Ignore List',		# Ingore list link
			'TagTitleConfPuppet'	=> 'Settings',			# Puppet settings link
			'TagTitleRealm'		=> 'Welcome to REALM',		# Realm title
			'TagPost'		=> 'Post',			# Post tag

			# Settings
			'SetTimeout'		=> '300',			# Time seconds for existence
			'SetPriColour'		=> '#FFFFFF',			# Primary colour
			'SetSecColour'		=> '#C0C0C0',			# Secondary colour
			'SetTextColour'		=> '#330033', 			# Text Colour

			# Links to next script
			'LnkPortal'		=> 'portal.plx',		# Portal link
			'LnkPrivate'		=> 'private.plx',		# Private message link
			'LnkRealm'		=> 'realm.plx',			# Link to realm
			'LnkWho'		=> 'who.plx',			# Who is on
			'LnkConfIgnore'		=> './config/config-ignore.plx',
			'LnkConfPuppet'		=> './config/config-puppet.plx',
			'LnkBlank'		=> 'http://www/blank.html',

			# Text entries
			'TxtSubmit'		=> 'Enter'			# Submit button text
		);
	}


	# Portal
	#
	# Information to change format and language of portal to realms

	elsif ($choice == 2)
	{
		DBMOpenPortal(\%portal);
		%portal = (
			'TagTitle'		=> 'Portal Title',		# Portal Title
			'TagSelectPuppet'	=> 'Select puppet', 		# Puppet selection prompt
			'TagSelectRealm'	=> 'Select realm',		# Realm selection prompt
			'TagSelectPrivate'	=> 'Private create/join',	# Option to create or join PR
			'TagLnkPuppet'		=> 'Puppet configuration',	# Puppet configuration
			'TagLnkPuppeteer'	=> 'Puppeteer configuration',	# Puppeteer configuration
			'TagLnkSupervisor'	=> 'Supervisory functions',	# Supervisory functions
			'TagLnkIgnore'		=> 'Ignore lists',		# Ignore tag
			'TagSecRealm'		=> 'Realm entrance',		# Realm entrance section
			'TagSecPuppeteer'	=> 'Puppeteers section',	# Puppeteers section

			# Text entries
			'TxtSubmitRealms'	=> 'Enter',			# Submit button text
			'TxtResetRealms'	=> 'Reset',			# Reset button text

			# Links to next script
			'LnkRealm'		=> 'realm.plx',			# Realm link
			'LnkPuppet'		=> './config/config-puppet.plx', 
			'LnkPuppeteer'		=> './config/config-puppeteer.plx',
			'LnkIgnore'		=> './config/config-ignore.plx',
			'LnkRealm'		=> './config/config-realm.plx'
		);
	}


	# Login
	#
	# Information to change format and language of login screen

	elsif ($choice == 3)
	{
		DBMOpenLogin(\%login);
		%login = (
			'TagTitleGeneral'	=> 'Login Title',		# Login title tag
			'TagTitleAdmin'		=> 'Admin login',		# Admin login tag
			'TagTitleRegister'	=> 'Registration',		# Registration tag
			'TagEMail'		=> 'Email address',		# EMail address tag
			'TagFullName'		=> 'Full Name',			# Full name tag
			'TagUsername'		=> 'Username:',			# Username tag
			'TagPassword'		=> 'Password:',			# Password tag
			'TagPasswordRepeat'	=> 'Repeat Password:',		# Repeat password
			'TagPasswordOld'	=> 'Old Password:',		# New password tag
			'TagOptJavacript'	=> 'Javascript options',	# Javascript options tag
			'TagOptChatPref'	=> 'Chat style',		# Chat style tag
			'TagOptFormat'		=> 'Chat format',		# Chat format

			# Grouped options (maintain order)
			'OptJavascript'		=> 'Use Javacript:No Javascript:Default',
			'OptChatPref'		=> 'Basic chat:Framed chat:Streaming chat:Default',
			'OptFormat'		=> 'Full formating:No images:Limited formating:Default',

			# Text options
			'TxtResetButton'	=> 'Clear',			# Clear button text 
			'TxtSubmitButton'	=> 'Login',			# Submit button text
			'TxtSubmitButtonSub'	=> 'Submit',			# Submit button text
			'TxtSubmitButtonAccept'	=> 'Accept',			# Submit button text

			# Links to next script
			'LnkPortal'		=> 'portal.plx',		# Portal link
			'LnkRealm'		=> 'realm.plx'			# Realm link
		);
	}


	# Configuration
	#
	# Generalized for configuration screens for the user, pupper and realm
	# This is to releive need for multiple hashes, when script are low priority

	elsif ($choice == 4)
	{
		DBMOpenConfiguration(\%config);
		%config = (
			'TagTitle'		=> 'Configuration',		# Configuration title

			# Realm tags
			'TagRealmLanguage'	=> 'Language options',		# Language options tag
			'TagRealmTags'		=> 'HTML Tag options',		# HTML tag options tag
			'TagRealmAccess'	=> 'Access control',		# Access control tag
			'TagRealmGuests'	=> 'Guest control',		# Guess access control tag
			'TagRealmInfo'		=> 'Realm Information',		# Realm information
			'TagRealmHeader'	=> 'Header',			# Realm header
			'TagRelamFooter'	=> 'Footer',			# Realm footer
			'TagRealmRealmSelect'	=> 'Select Realm',		# Select Realm display
			'TagRealmRealmFunction'	=> 'Function',			# Realm function
			'TagRealmBannings',	=> 'Bannings',			# Banning control
			'TagRealmWords',	=> 'Word Restrictions',		# Word Restriction

			# Puppeteer tags
			'TagConfPassword'	=> 'Change password', 		# Password change prompt
			'TagConfEMail'		=> 'Change email address',	# EMail changeover
			'TagConfIgnore'		=> 'Ignore list', 		# Ignore list
			'TagConfSuccess'	=> 'Change successful',		# Change successful

			# Error messages
			'ErrPassword'		=> 'Invalid Password',		# Invalid password
			'ErrMismatch'		=> 'Passwords do not match',	# Mismatched passwords
			'ErrEMail'		=> 'Email address is invalid',	# Not proper E-Mail

			# Puppet related
			'TagPupImageLink'	=> 'Image Link',		# Image Link
			'TagPupTagline'		=> 'Tagline',			# Tagline tag
			'TagPupBio'		=> 'Puppet bio',		# Bio title change tag 
			'TagPupAddition'	=> 'Addition',			# Addition button
			'TagPupDelSelect'	=> 'Select/Delete',		# Delete select button
			'TagPupName'		=> 'Puppet Name',		# Puppet name
			'TagPupTitle'		=> 'Tilte',			# Title 
			'TagPupImgHeight'	=> 'Image Height',		# Image Height
			'TagPupImgWidth'	=> 'Image Width',		# Image Width

			# General
			'TagGenAdd'		=> 'Add',			# Add tag
			'TagGenRemove'		=> 'Remove',			# Remove tag

			# Grouped options (maintain order)
			'OptLanugage'		=> 'relaxed:restricted',
			'OptTags'		=> 'relaxed:restricted',
			'OptAccess'		=> 'relaxed:restricted:list',
			'OptGuests'		=> 'Allow:Disallow:Posting',

			# Text options
			'TxtResetButton'	=> 'Reset',			# Clear button text 
			'TxtSubmitButton'	=> 'Submit',			# Submit button text
			'TxtSubmitView'		=> 'View',			# View button
			'TxtSubmitDelete'	=> 'Delete',			# Delete button
			'TxtSubmitAddition'	=> 'Add'			# Addition button
		);
	}


	# Chat
	#
	# Since these tags are used in multiple scipts they were seperated

	elsif ($choice == 5)
	{
		DBMOpenChat(\%chat);
		%chat = (
			# Settings
			'SetBGColor'		=> '#FFFFFF',			# Background colour
			'SetTop'		=> '<--->',			# Top part
			'SetTitleSize'		=> '+1',			# Size of title
			'SetStreamSize'		=> '5000000',			# Streaming limit

			# Tags
			'TagTextColour'		=> 'Textcolour',		# Text colour tag
			'TagTextSize'		=> 'Textsize',			# Text size tag
			'TagPuppet'		=> 'Puppet',			# Puppet prompt tag
			'TagPuppetTo'		=> 'To',			# Puppet to
			'TagPuppetPMTo'		=> '<B>To</B>',			# Puppet PM to
			'TagPuppetPMFrom'	=> '<B>From</B>',		# Puppet PM from
			'TagPuppetBio'		=> '[bio]',			# Puppet bio

			'TagLnkPuppet'		=> '[Config]',			# Cofiguration		
			'TagLnkIgnore'		=> '[Ignore]',			# Ignore
			'TagLnkPrivate'		=> '[Private]',			# Private
			'TagLnkWho'		=> '[Who]',			# Who am I
			'TagLnkImage'		=> '[Image]',			# Image link
			'TagLnkReload'		=> '[Reload]', 			# Reload button
			'TagSeperator'		=> '<BR>',			# Seperator
	
			# Options
			'OptTextColour'		=> 'Black:Grey:Silver:Fuschia:Green:Lime:Olive:Teal:Blue:Navy:Purple:Maroon:Red',
			'OptTextColourHex'	=> '#000000:#666666:#999999:#FF99FF:#009900:#33FF33:#999900:#408080:#3333FF:#000099:#663366:#993366:#FF6666',	
			'OptTextSize'		=> '-2:-1:+1:+2:+3',

			# Text options
			'TxtSubmitButton'	=> 'Post/View',			# Submit button text
			'TxtResetButton'	=> 'Clear',			# Reset button text

			'LnkPuppet'		=> './config/config-puppet.plx', 
			'LnkPuppeteer'		=> './config/config-puppeteer.plx',
			'LnkIgnore'		=> './config/config-ignore.plx',
			'LnkWho'		=> './post/who.plx',
			'LnkPrivate'		=> './post/private.plx',
			'LnkBio'		=> './bio.plx'
		);
	}


	# System
	#
	# Information that affects core operations, such as timeouts, addresses
	# defaults for new users, realms et cetera.

	elsif ($choice == 6)
	{
		DBMOpenSystem(\%system);
		%system = (
			# Settings
			'SetTimeDay'		=> '86400',			# Seconds in a day
			'SetTimeoutRegister'	=> '5',				# Timeout (days) for registration
			'SetTimeoutBanned'	=> '5',				# Tiemout (days) for ban on puppeteer
			'SetTimeoutRealm'	=> '1',				# Timeout (days) for ban on realm
			'SetTimeoutPuppeteer'	=> '90',			# Timeout (days) for puppeteer idle
			'SetAllowPrivateRealm'	=> 'yes',			# Restrict private realm creations
			'SetAllowPrivateMsg'	=> 'yes',			# Restrict sending of private messages
			'SetInfoServer'		=> 'Ethereal Realms',		# Server name
			'SetInfoContactName'	=> 'Webmaster',			# Contact name
			'SetInfoContactAddress'	=> 'webmaster',			# Contact email address
			
			# Location
			'LocSendmail'		=> '/usr/sbin/sendmail',	# Sendmail location
			'LocScriptReg'		=> 'http://www/cgi-bin/registration.plx',
			'LocTemp'		=> '/tmp'			# Temporary storage folder
		);
	}

	# All
	elsif ($choice == 99)
	{
		# Call each individual function
		DBMResetMySQL();
		DBMResetRealm();
		DBMResetPortal();
		DBMResetLogin();
		DBMResetConfiguration();
		DBMResetChat();
		DBMResetSystem();
	}

	$bypass = 0;						# Reset bypass to normal (false)
}

# Alias for
sub DBMResetMySQL
{ DBMReset(0); }

# Alias for Realm
sub DBMResetRealm
{ DBMReset(1); }

# Alias for Portal
sub DBMResetPortal
{ DBMReset(2); }

# Alias for Login
sub DBMResetLogin
{ DBMReset(3); }

# Alias for Configuration
sub DBMResetConfiguration
{ DBMReset(4); }

# Alias for Chat
sub DBMResetChat
{ DBMReset(5); }

# Alias for System
sub DBMResetSystem
{ DBMReset(6); }

# Alias for All DBMs
sub DBMResetAll
{ DBMReset(99); }

								
1;								# Return true
