#!/bin/perl -w
#################################################################################
# Created       : Martin Foster
# Modified      : 05/23/2000
#################################################################################
#
# Chat configuration - Script part of Webchat designed to configure MySQL for use 
# Copyright (C) 2000  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : mfoster@redwhite.com
#       Address : Suite 209 - 355 5th Ave NE
#                 Calgary, Alberta
#                 T2E 0K9
#
#################################################################################

use CGI qw(:standard);						# Common gateway interface
use CGI::Carp qw(fatalsToBrowser);				# CGI Error logs
use strict;							# Strict variable enforcement

use Webchat::Database;						# Database handler
use Webchat::Dbm;						# DBM Addition
use Webchat::Login;						# Login controls
use Webchat::Param;						# Parameter control

#################################################################################
# Data Members
#################################################################################

my $Database;							# Database handle
my $cgi;							# CGI Handle
my %param;							# Parameter list

#################################################################################
# Program Area
#################################################################################

	$cgi = new CGI;						# New CGI handle
	Webchat::Param::GetParam($cgi, \%param);		# Param to Hash
	Webchat::Database::DatabaseConnect(\$Database);		# Connect to MySQL

	print $cgi->header();					# File header
	print $cgi->start_html('Webchat configuration');	# HTML header

	if (Webchat::Login::GetVerificationAdmin($Database, $cgi, \%param))
	{
		print $cgi->p( $cgi->h1('Webchat Tag Administration'));
		print $cgi->start_form();			# Start form

		DataHandlerAll($cgi, \%param);

		print $cgi->p($cgi->submit(), $cgi->reset()), "\n";
		Webchat::Param::EmbedNormal($Database, $cgi, 'USER', $param{'USER'}, 'CRYPT', $param{'CRYPT'});
		print $cgi->end_form(), "\n";
	}

	print $cgi->end_html;					# End HTML
	$Database->disconnect();				# Disconnect database	


#################################################################################
# Sub-Routines
#################################################################################

#####################
# DataHandler
#
# Takes in a CGI handle and the name of the hash to activate and displays 
# information within those hashes.   If changes, will make the change neccesary.

sub DataHandler							# CGI, Number for hash
{
	#####################
	# Data members
	my $cgi = shift;					# Cgi filehandle
	my $param = shift;					# Hash of parameters					
	my $choice = shift;					# Choice of hash to open

	my $dbm;						# DBM being used
	my $key;						# Arbitrary key
	my $value;						# Arbitrary value

	my %hash;						# Arbitrary hash


	#####################
	# Program area

	# Determine appropriate dbm to open and assign value to dbm scalar
	if ($choice == 0)					# MySQL
	{ Webchat::Dbm::DBMOpenMySQL(\%hash);  $dbm = 'MySQL'; }
	elsif ($choice == 1)					# Realm
	{ Webchat::Dbm::DBMOpenRealm(\%hash);  $dbm = 'Realm'; }
	elsif ($choice == 2)					# Portal
	{ Webchat::Dbm::DBMOpenPortal(\%hash); $dbm = 'Portal'; }
	elsif ($choice == 3)					# Login
	{ Webchat::Dbm::DBMOpenLogin(\%hash);  $dbm = 'Login'; }
	elsif ($choice == 4)					# Configuration
	{ Webchat::Dbm::DBMOpenConfiguration(\%hash); $dbm = 'Configuration'; } 
	elsif ($choice == 5)					# Chat
	{ Webchat::Dbm::DBMOpenChat(\%hash);   $dbm = 'Chat'; }
	elsif ($choice == 6)					# System
	{ Webchat::Dbm::DBMOpenSystem(\%hash); $dbm = 'System'; }
	elsif ($choice == 99)					# All dbms
	{
		# Call each data hander seperately
		DataHandler($cgi, $param, 0);
		DataHandler($cgi, $param, 1);
		DataHandler($cgi, $param, 2);
		DataHandler($cgi, $param, 3);
		DataHandler($cgi, $param, 4);
		DataHandler($cgi, $param, 5);
		DataHandler($cgi, $param, 6);
	}

	# Only complete following if under 99
	if ($choice < 99)
	{
		DisplayHandlerHeading($cgi, $dbm);
		DisplayHandlerTop($cgi, $dbm);
		DisplayHandlerTitle($cgi, $dbm);	

		# Loop through and display information
		foreach $choice (sort keys %hash)
		{
			# If diffrent change
			if ((defined($param->{"$dbm$choice"})) && ($param->{"$dbm$choice"} ne $hash{$choice})) 
			{
				# Assign value and display
				$hash{$choice} = $param->{"$dbm$choice"};
				DisplayHandlerNewInfo($cgi, $dbm, $choice, 'yes', $hash{$choice});
			}
			
			# Else display as no one really cares
			else
			{
				DisplayHandlerInfo($cgi, $dbm, $choice, 'no', $hash{$choice});
			}
		}

		DisplayHandlerBottom($cgi, $dbm);

		# Unlink hash from dbm
		Webchat::Dbm::DBMClose(\%hash);
	}
}

# Alias for MySQL
sub DataHandlerMySQL
{ DataHandler(shift, shift, 0); }

# Alias for Realm
sub DataHandlerRealm
{ DataHandler(shift, shift, 1); }

# Alias for Portal
sub DataHandlerPortal
{ DataHandler(shift, shift, 2); }

# Alias for Login
sub DataHandlerLogin
{ DataHandler(shift, shift, 3); }

# Alias for Configuration
sub DataHandlerConfiguration
{ DataHandler(shift, shift, 4); }

# Alias for Chat
sub DataHandlerChat
{ DataHandler(shift, shift, 5); }

# Alias for System
sub DataHandlerSystem
{ DataHandler(shift, shift, 6); }

# Alias for all
sub DataHandlerAll
{ DataHandler(shift, shift, 99); }


#####################
# DisplayHandler
#
# Make formatted tables based on information received and options. 

sub DisplayHandler
{
	#####################
	# Data members
	my $cgi = shift;					# Cgi filehandle
	my $choice = shift;					# Choice of hash to open
	my $dbm = shift;					# DBM being worked on

	my @title = qw(Key Change Value);			# Titles


	#####################
	# Program area

	# Top of Table
	if ($choice == 0)					# Table top
	{  
		print "<TABLE COLS=3 WIDTH=\"100%\">\n";
	}

	# Title section of table
	elsif ($choice == 1)					# Table title
	{
		print "\t<TR>\n";				# Row beginning

		# Print first three title columns
		print "\t\t<TD WIDTH=\"200\"><B><FONT SIZE=+1>$title[0]</FONT></B></TD>\n";
		print "\t\t<TD WIDTH=\"50\"><FONT SIZE=+1><B>$title[1]</FONT></B></TD>\n";
		print "\t\t<TD><FONT SIZE=+1><B>$title[2]</FONT></B></TD>\n";		

		print "\t</TR>\n";				# Row end
	}

	# Information row of table
	elsif ($choice == 2)					# Table data
	{
		print "\t<TR>\n";				# Row beginning

		# Print three columns of data
		print "\t\t<TD><B>$_[0]</B></TD>\n";
		print "\t\t<TD><FONT COLOR=\"\#00CC00\">$_[1]</FONT></TD>\n";
		print "\t\t<TD>", $cgi->textfield("$dbm$_[0]",$_[2],80,180), "</TD>\n";

		print "\t</TR>\n";				# Row end
	}

	# Information row of table
	elsif ($choice == 3)					# Table data
	{
		print "\t<TR>\n";				# Row beginning

		# Print three columns of data
		print "\t\t<TD><B>$_[0]</B></TD>\n";
		print "\t\t<TD><FONT COLOR=\"\#FF0000\">$_[1]</FONT></TD>\n";
		print "\t\t<TD>", $cgi->textfield("$dbm$_[0]",$_[2],80,180), "</TD>\n";

		print "\t</TR>\n";				# Row end
	}

	# Bottom of table
	elsif ($choice == 4)					# Table bottom
	{
		print "</TABLE>\n";
	}

	# Heading of table
	elsif ($choice == 5)					# Table bottom
	{
		print "<BR>\n<BR>\n<B><FONT SIZE=+2>$dbm</FONT></B>\n<BR>\n";
	}
}

# Alias table top
sub DisplayHandlerTop
{ DisplayHandler(shift, 0, shift); }

# Alias table bottom
sub DisplayHandlerBottom
{ DisplayHandler(shift, 4, shift); }

# Alias table title
sub DisplayHandlerTitle
{ DisplayHandler(shift, 1, shift); }

# Alias table info
sub DisplayHandlerInfo
{ DisplayHandler(shift, 2, shift, @_); }

# Alias table new info
sub DisplayHandlerNewInfo
{ DisplayHandler(shift, 3, shift, @_); }

# Alias table heading
sub DisplayHandlerHeading
{ DisplayHandler(shift, 5, shift); }
