#!/bin/perl
#################################################################################
# Created       : Martin Foster
# Modified      : 05/23/2000
#################################################################################
#
# Configure Ignore - Script part of Webchat designed to configure ignore lists
# Copyright (C) 2000  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : mfoster@redwhite.com
#       Address : Suite 209 - 355 5th Ave NE
#                 Calgary, Alberta
#                 T2E 0K9
#
#################################################################################

use CGI qw(:standard);						# Common gateway interface
use CGI::Carp qw(fatalsToBrowser);				# CGI Error logs
use strict;							# Strict variable enforcement

use String::Random;						# Random String generator

use Webchat::Database;						# Database handler
use Webchat::Dbm; 						# DBM Addition
use Webchat::Login;						# Login functionality
use Webchat::Param;						# Parameter control
use Webchat::Table;						# Table control


#################################################################################
# Data Members
#################################################################################
my $Database;							# Database handle
my $cgi;							# Common gateway interface handle

my %param;							# Parameter hash
my %config;							# Configuration tag

#################################################################################
# Program Area
#################################################################################

	$cgi = new CGI;						# Create CGI Handle

	Webchat::Database::DatabaseConnect(\$Database);		# Connect to MySQL
	Webchat::Param::GetParam($cgi, \%param);		# Retreive parameters
	Webchat::Dbm::DBMOpenConfig(\%config);			# Attach hash

	print $cgi->header();					# File header
	Webchat::Database::DocumentGetHeader($Database);	# HTML header

	# Authenthication
	if ( Webchat::Login::GetVerificationNormal($Database, $cgi, \%param) )
	{
		print "$config{'TagTitle'}\n<BR>\n";		# Print title

		InitialDisplay($Database, $cgi, \%param);
	}


	Webchat::Database::DocumentGetFooter($Database);	# HTML footer

	Webchat::Dbm::DBMClose(\%config);			# Release hash
	$Database->disconnect();				# Disconnect database handle

#################################################################################
# Sub-Routines
#################################################################################

#####################
# InitialDisplay
#
# Handles the general output of the initial display screen.  Which will allow one
# to change password, E-Mail addresses and/or passwords.

sub InitialDisplay						# Database, CGI, Param
{
	#####################
	# Data members
	my $Database = shift;					# Database handle
	my $cgi = shift;					# CGI handle
	my $param = shift;					# Parameter handle
	
	my %config;						# Config hash

	my $puppets;						# List of puppets
	my $ignored;						# List of the dammed

	my @puppets;						# List of puppets
	my @ignored;						# List of the dammed
	

	#####################
	# Program area	
	
	# Link DBMs with hashes
	Webchat::Dbm::DBMOpenConfig(\%config);

	# Information handling
	# Addition into list
	if (defined($param->{$config{'TxtSubmitAddition'}}))
	{
		# Insert information
		$Database->do("INSERT INTO PuppetIgnore VALUES (?,?)",
				{}, $param->{'USER'}, $param->{'LIST'});
	}

	# Removal from list
	elsif (defined($param->{$config{'TxtSubmitDelete'}}))
	{
		# Remove ignored person
		$Database->do("DELETE FROM PuppetIgnore WHERE PuppeteerLogin=? AND PuppetName=?",
 			{}, $param->{'USER'}, $param->{'IGNORE'});

	}

	# Cleanup
	delete $param->{$config{'TxtSubmitAddition'}};
	delete $param->{$config{'TxtSubmitDelete'}};

	
	# Retreive lists
	Webchat::Database::GetListPuppetOther($Database, \@puppets, $param->{'USER'});
	Webchat::Database::GetListPuppetIgnored($Database, \@ignored, $param->{'USER'});

	# Confihure widgets
	$puppets = $cgi->scrolling_list('LIST',   \@puppets, $puppets[0], 10);
	$ignored = $cgi->scrolling_list('IGNORE', \@ignored, $ignored[0], 10);


	# Ignore list
	# Display of information
	print $cgi->start_form();

	Webchat::Table::MakeTop($cgi);
	Webchat::Table::MakeSingle($cgi, $config{'TagConfIgnore'});
	Webchat::Table::MakeBlank($cgi);

	# Additions and removal control	
	Webchat::Table::MakeValid($cgi, $puppets, $cgi->submit($config{'TxtSubmitAddition'}));
	Webchat::Table::MakeBlank($cgi);
	Webchat::Table::MakeValid($cgi, $ignored, $cgi->submit($config{'TxtSubmitDelete'}));
	Webchat::Table::MakeBottom($cgi);

	# Embed
	Webchat::Param::EmbedNormal($Database, $cgi, %{$param});
	print $cgi->end_form(), "\n";

	# Free DBM and hash
	Webchat::Dbm::DBMClose(\%config);
}
